// 
// Patron pour la generation d'une classe derivee dans ROOT
// FVariableNameField derive de TNamed
// 
 
#ifndef FVariableNameField_h 
#define FVariableNameField_h 
 
#include "TNamed.h" 
#include "TString.h" 
 
class FVariableNameField : public TNamed { 
 
   private:
   	Int_t	min;
	Int_t 	max;
	Int_t	step;
	Int_t   rank;
	TString format;
	Bool_t  decoded;
   
   protected: 
        virtual void Init(void);       // initialisation 
	virtual void DecodeDescription(void);
        virtual void RefreshDescription(void);
 
   public:	 
   	FVariableNameField(void);    // constructeur par defaut 
	FVariableNameField(const FVariableNameField &ap); // constructeur par copie 
	
	~FVariableNameField(void);		// desctructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	FVariableNameField& operator = (const FVariableNameField &hp); // operateur = 
 
 	virtual void SetDeclaration(const Char_t *dec);
	virtual const Char_t *GetDeclaration(void) {return GetTitle();}
	virtual void SetMin(Int_t m) {min=m;if(decoded)RefreshDescription();}
	virtual void SetMax(Int_t m) {max=m;if(decoded)RefreshDescription();}
	virtual void SetStep(Int_t m=1) {step=m;if(decoded)RefreshDescription();}
	virtual void SetRank(Int_t m=0) {rank=m;if(decoded)RefreshDescription();}
	virtual void SetFormat(const Char_t *f="%d") {format=f;if(decoded)RefreshDescription();}
	virtual void SetFormat(TString f) {format=f;if(decoded)RefreshDescription();}
	virtual Int_t GetMin(void) {return min;}
	virtual Int_t GetMax(void) {return max;}
	virtual Int_t GetStep(void) {return step;}
	virtual Int_t GetRank(void) {return rank;}
	virtual const Char_t *GetFormat(void) {return format.Data();}
	virtual const Char_t *GetString(Int_t i);
	virtual Int_t GetNbValues(void){return (max-min)/step+1;}

        virtual Int_t Compare(const TObject *obj) const;
        virtual void  ls(Option_t *option="") const;
 
 
    ClassDef(FVariableNameField,1)
 
}; 
 
#endif 
 
