// 
// Patron pour la generation d'une classe derivee dans ROOT
// RHVOscillo derive de TGCompositeFrame
// 
 
#ifndef RHVOscillo_h 
#define RHVOscillo_h 
 
#include "TROOT.h"
#include "TGFrame.h"
#include "TCanvas.h"
#include "TGButton.h"
#include "TGLabel.h"
#include "TList.h"
 
class RHVOscillo : public TGCompositeFrame { 
   private:
	TGTextButton *nextOscPage;
	TGTextButton *prevOscPage;
        TGLabel	     *oscPageLabel;

   protected: 
	TList	*listOfHistos;
	TCanvas	*canvasOscillo;
	TGCompositeFrame *cfOsc;
	TGCompositeFrame *currentOscBoutFrame;
	
	TGLayoutHints	*eX;
        TGButton *curBout;
        Pixel_t   boutCol;
  	Pixel_t   boutColRefOn;
	Pixel_t   boutColRefOff;
        TGCheckButton *markersButton;
	TList	*listOfOscPages;
	Int_t   currentOscPageNumber;
	Int_t   oscPageNumber;
	
   protected: 
        virtual void Init(void);       // initialisation 
 
   public:	 
	RHVOscillo(const TGWindow *p=0,UInt_t w=500,UInt_t h=300);
#if ROOT_VERSION_CODE <= ROOT_VERSION(5,12,0)
	RHVOscillo(const RHVOscillo &ap); // constructeur par copie 
#endif
	
	~RHVOscillo(void);		// destructeur; 
	 
#if ROOT_VERSION_CODE >= ROOT_VERSION(3,4,0)
   	virtual void Copy(TObject & obj) const;
#else
   	virtual void Copy(TObject & obj);
#endif
	RHVOscillo& operator = (const RHVOscillo &hp); // operateur = 
 
	virtual Bool_t ProcessMessage(Long_t msg, Long_t par1, Long_t par2); 

	virtual TCanvas *GetCanvas(void) {return canvasOscillo;}
	virtual void SetListOfHistos(TList *l);
	virtual void BuildOscButtons(void);
	virtual void Reset(void);
	virtual void WarningBox(char const *title="Warning",char const *msg="Warning");
  	virtual void LoadOscillo(const Char_t *name=0);
 	virtual void HighlightCurrentButton(void);
  	virtual void RefreshMarkers(Bool_t mark);
        virtual TGTextButton *GetMarkersButton(void) { return markersButton;}
 	virtual void ShowNextOscPage(void);
 	virtual void ShowPrevOscPage(void);
 	virtual void ShowOscPage(Int_t n);
 	virtual void HideAllOscPages(void);
 	virtual Int_t GetCurrentOscPage(void) { return currentOscPageNumber;}

    ClassDef(RHVOscillo,1)
 
}; 
 
#endif 
 
